<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AddBlock</name>
    <message>
        <source>&amp;Add Block</source>
        <translation type="obsolete">&amp;Aggiungi Blocco</translation>
    </message>
    <message>
        <location filename="../AddBlockInit.js" line="+2"/>
        <source>&amp;Add Empty Block</source>
        <translation>&amp;Aggiungi blocco</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Add new empty block</source>
        <translation>Aggiungere un nuovo blocco vuoto</translation>
    </message>
</context>
</TS>
